unquad.strategy.cross\_val.CrossValidation
==========================================

.. currentmodule:: unquad.strategy.cross_val

.. autoclass:: CrossValidation

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CrossValidation.__init__
      ~CrossValidation.fit_calibrate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CrossValidation.calibration_ids
   
   